@@ -5,10 +5,24 @@ require 5.005;  # 4-arg substr
 use strict;
 use vars qw($VERSION);
 
-$VERSION = "5.815";
+$VERSION = "5.832";
 
 my $CRLF = "\015\012";   # "\r\n" is not portable
 
+*_bytes = defined(&utf8::downgrade) ?
+    sub {
+        unless (utf8::downgrade($_[0], 1)) {
+            require Carp;
+            Carp::croak("Wide character in HTTP request (bytes required)");
+        }
+        return $_[0];
+    }
+    :
+    sub {
+        return $_[0];
+    };
+
+
 sub new {
     my $class = shift;
     unshift(@_, "Host") if @_ == 1;
@@ -173,7 +187,7 @@ sub format_request {
 	push(@h2, "Host: $h") if $h;
     }
 
-    return join($CRLF, "$method $uri HTTP/$ver", @h2, @h, "", $content);
+    return _bytes(join($CRLF, "$method $uri HTTP/$ver", @h2, @h, "", $content));
 }
 
 
@@ -185,13 +199,13 @@ sub write_request {
 sub format_chunk {
     my $self = shift;
     return $_[0] unless defined($_[0]) && length($_[0]);
-    return sprintf("%x", length($_[0])) . $CRLF . $_[0] . $CRLF;
+    return _bytes(sprintf("%x", length($_[0])) . $CRLF . $_[0] . $CRLF);
 }
 
 sub write_chunk {
     my $self = shift;
     return 1 unless defined($_[0]) && length($_[0]);
-    $self->print(sprintf("%x", length($_[0])) . $CRLF . $_[0] . $CRLF);
+    $self->print(_bytes(sprintf("%x", length($_[0])) . $CRLF . $_[0] . $CRLF));
 }
 
 sub format_chunk_eof {
@@ -200,7 +214,7 @@ sub format_chunk_eof {
     while (@_) {
 	push(@h, sprintf "%s: %s$CRLF", splice(@_, 0, 2));
     }
-    return join("", "0$CRLF", @h, $CRLF);
+    return _bytes(join("", "0$CRLF", @h, $CRLF));
 }
 
 sub write_chunk_eof {
@@ -227,6 +241,7 @@ sub my_read {
 
 sub my_readline {
     my $self = shift;
+    my $what = shift;
     for (${*$self}{'http_buf'}) {
 	my $max_line_length = ${*$self}{'http_max_line_length'};
 	my $pos;
@@ -234,7 +249,7 @@ sub my_readline {
 	    # find line ending
 	    $pos = index($_, "\012");
 	    last if $pos >= 0;
-	    die "Line too long (limit is $max_line_length)"
+	    die "$what line too long (limit is $max_line_length)"
 		if $max_line_length && length($_) > $max_line_length;
 
 	    # need to read more data to find a line ending
@@ -251,7 +266,7 @@ sub my_readline {
                     }
                     # if we have already accumulated some data let's at least
                     # return that as a line
-                    die "read failed: $!" unless length;
+                    die "$what read failed: $!" unless length;
                 }
                 unless ($n) {
                     return undef unless length;
@@ -259,7 +274,7 @@ sub my_readline {
                 }
             }
 	}
-	die "Line too long ($pos; limit is $max_line_length)"
+	die "$what line too long ($pos; limit is $max_line_length)"
 	    if $max_line_length && $pos > $max_line_length;
 
 	my $line = substr($_, 0, $pos+1, "");
@@ -297,7 +312,7 @@ sub _read_header_lines {
     my @headers;
     my $line_count = 0;
     my $max_header_lines = ${*$self}{'http_max_header_lines'};
-    while (my $line = my_readline($self)) {
+    while (my $line = my_readline($self, 'Header')) {
 	if ($line =~ /^(\S+?)\s*:\s*(.*)/s) {
 	    push(@headers, $1, $2);
 	}
@@ -325,7 +340,7 @@ sub read_response_headers {
     my($self, %opt) = @_;
     my $laxed = $opt{laxed};
 
-    my($status, $eol) = my_readline($self);
+    my($status, $eol) = my_readline($self, 'Status');
     unless (defined $status) {
 	die "Server closed connection without sending any data back";
     }
@@ -457,11 +472,11 @@ sub read_entity_body {
 	#   $chunked > 0:    bytes left in current chunk to read
 
 	if ($chunked <= 0) {
-	    my $line = my_readline($self);
+	    my $line = my_readline($self, 'Entity body');
 	    if ($chunked == 0) {
 		die "Missing newline after chunk data: '$line'"
 		    if !defined($line) || $line ne "";
-		$line = my_readline($self);
+		$line = my_readline($self, 'Entity body');
 	    }
 	    die "EOF when chunk header expected" unless defined($line);
 	    my $chunk_len = $line;
